EmptyDArgon2Flutter class

The empty DArgon2Platform implementation to default to when no platform provides bindings to set to.

Inheritance

Constructors

EmptyDArgon2Flutter()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

hashPasswordBytes(List<int> password, {required Salt salt, int iterations = 32, int memory = 256, int parallelism = 2, int length = 32, Argon2Type type = Argon2Type.i, Argon2Version version = Argon2Version.V13}) → Future<DArgon2Result>
The Future method to hash a List
hashPasswordString(String password, {required Salt salt, int iterations = 32, int memory = 256, int parallelism = 2, int length = 32, Argon2Type type = Argon2Type.i, Argon2Version version = Argon2Version.V13}) → Future<DArgon2Result>
The Future method to hash a String password with Argon2
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
verifyHashBytes(List<int> password, List<int> encodedHash, {Argon2Type type = Argon2Type.i}) → Future<bool>
The Future method to handle verifying a List
verifyHashString(String password, String encodedHash, {Argon2Type type = Argon2Type.i}) → Future<bool>
The Future method to handle verifying a String argon2 hash against a String password
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited